@@ -342,6 +342,7 @@ class DuckDB(Dialect):
             "ONLY": TokenType.ONLY,
             "PIVOT_WIDER": TokenType.PIVOT,
             "POSITIONAL": TokenType.POSITIONAL,
+            "RESET": TokenType.COMMAND,
             "SIGNED": TokenType.INT,
             "STRING": TokenType.TEXT,
             "SUMMARIZE": TokenType.SUMMARIZE,
@@ -416,7 +417,9 @@ class DuckDB(Dialect):
             "JSON": exp.ParseJSON.from_arg_list,
             "JSON_EXTRACT_PATH": parser.build_extract_json_with_path(exp.JSONExtract),
             "JSON_EXTRACT_STRING": parser.build_extract_json_with_path(exp.JSONExtractScalar),
+            "LIST_CONTAINS": exp.ArrayContains.from_arg_list,
             "LIST_HAS": exp.ArrayContains.from_arg_list,
+            "LIST_HAS_ANY": exp.ArrayOverlaps.from_arg_list,
             "LIST_REVERSE_SORT": _build_sort_array_desc,
             "LIST_SORT": exp.SortArray.from_arg_list,
             "LIST_VALUE": lambda args: exp.Array(expressions=args),
@@ -662,6 +665,7 @@ class DuckDB(Dialect):
         ARRAY_CONCAT_IS_VAR_LEN = False
         ARRAY_SIZE_DIM_REQUIRED = False
         NORMALIZE_EXTRACT_DATE_PARTS = True
+        SUPPORTS_LIKE_QUANTIFIERS = False
 
         TRANSFORMS = {
             **generator.Generator.TRANSFORMS,
